@@ -13,10 +13,10 @@ def load_data(
         file_path_with_price_data,
         strategy_hyperparameters,
         file_path_with_token_data=None,
-        name_of_foreign_key_in_transaction_table=None,
+        name_of_foreign_key_in_price_data_table=None,
         name_of_foreign_key_in_token_metadata_table=None
     ):
-    """Loads transactional data and metadata.
+    """Loads price data and metadata.
 
     This function loads prices and token metadata (token data). It also uses the
     date as an index.
@@ -58,7 +58,7 @@ def load_data(
         df_prices = merge_data(
             df_prices=df_prices,
             df_token_metadata=df_token_metadata,
-            name_of_foreign_key_in_transaction_table=name_of_foreign_key_in_transaction_table,
+            name_of_foreign_key_in_price_data_table=name_of_foreign_key_in_price_data_table,
             name_of_foreign_key_in_token_metadata_table=name_of_foreign_key_in_token_metadata_table
         )
 
@@ -81,15 +81,15 @@ def load_data(
 def merge_data(
         df_prices,
         df_token_metadata,
-        name_of_foreign_key_in_transaction_table,
+        name_of_foreign_key_in_price_data_table,
         name_of_foreign_key_in_token_metadata_table
     ):
-    """Enriches transactional data with metadata about the tokens."""
+    """Enriches price data with metadata about the tokens."""
 
     df_prices_enriched_with_metadata = merge(
         df_prices,
         df_token_metadata,
-        left_on=name_of_foreign_key_in_transaction_table,
+        left_on=name_of_foreign_key_in_price_data_table,
         right_on=name_of_foreign_key_in_token_metadata_table
     )
 
@@ -99,7 +99,7 @@ def prepare_data(
         file_path_with_price_data,
         strategy_hyperparameters,
         file_path_with_token_data=None,
-        name_of_foreign_key_in_transaction_table=None,
+        name_of_foreign_key_in_price_data_table=None,
         name_of_foreign_key_in_token_metadata_table=None
     ):
     """Loads prices and token data and joins those into a pandas DataFrame."""
@@ -108,7 +108,7 @@ def prepare_data(
         file_path_with_price_data=file_path_with_price_data,
         file_path_with_token_data=file_path_with_token_data,
         strategy_hyperparameters=strategy_hyperparameters,
-        name_of_foreign_key_in_transaction_table=name_of_foreign_key_in_transaction_table,
+        name_of_foreign_key_in_price_data_table=name_of_foreign_key_in_price_data_table,
         name_of_foreign_key_in_token_metadata_table=name_of_foreign_key_in_token_metadata_table
     )
 
